@@ -729,6 +729,35 @@ class BaseEnvironnement(BaseEstimator):
                 max_gradient_norm=max_gradient_norm
             )
         self.to(control.device)
+        state_in_loss = list(
+            filter(
+                lambda x: 
+                    (
+                        x.lower() == 'state' or
+                        x.lower() == 'fitstate' or
+                        x.lower() == 'fit_state'
+                    ),
+                loss_fn.__code__.co_varnames
+            )
+        )
+        state_in_loos_kargs = list(
+            filter(
+                lambda x: x == 'kargs' or x == 'kwargs',
+                loss_fn.__code__.co_varnames
+            )
+        )
+        if len(state_in_loss) == 1:
+            loss_kargs[state_in_loss[0]] = state
+        elif len(state_in_loss) > 1:
+            warn(
+                "Plusieurs clefs trouvé pouvant correspondre à l'argument "
+                "state dans les entrées de la fonction loss : "
+                f"{', '.join(state_in_loss)}, du coupe ne nom d'argument "
+                "state sera choisi par défaut."
+            )
+            loss_kargs['state'] = state
+        elif len(state_in_loos_kargs) == 1:
+            loss_kargs['state'] = state
 
         list_callbacks.begin_train(self, dataset, state, control, None)
         try:
