@@ -71,6 +71,9 @@ class FitControl:
         Booléen indiquant si le processus d'apprentissage a divergé ou non.
     target_field: str (='target')
         Nom du champ de la target dans le dictionnaire d'échange.
+    target_checktensor: bool (=True)
+            Permet de checker si le champs target est un tensor, sinon le
+            converti. Si False ne checke pas si le champs est un tensor.
     device : device (=device('cpu:0'))
         Device sur le quel le modèle exécute son entrainement.
     mixed_type_gpu : bool (=False)
@@ -88,6 +91,7 @@ class FitControl:
     training_stop: bool = False
     diverge: bool = False
     target_field: str = 'target'
+    target_checktensor: bool = True
     device: torch_device = torch_device('cpu:0')
     mixed_type_gpu: bool = False
     grad_scaler: GradScaler = GradScaler(enabled=False)
